#
# spec file for package ipmitool
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ipmitool
Version:        1.8.19.13.gbe11d94
Release:        2.2
Summary:        Utility for IPMI Control
License:        BSD-3-Clause
Group:          System/Management
URL:            https://github.com/ipmitool/ipmitool
Source:         %{name}-%{version}.tar.xz
Source1:        ipmievd.service
Source2:        ipmievd.sysconf
Source3:        enterprise-numbers
Patch1:         0001-Enhance-fwum-output.patch
Patch2:         0002-Fix-file-permissions.patch
Patch3:         0003-Cleanup-and-compiler-issues-only-no-functional-chang.patch
Patch4:         0004-Adjust-SUSE-paths.patch
Patch5:         0005-HPM-x-compatibility-message-is-DEBUG-only.patch
Patch6:         Fix-time-format-for-sel-list-v.patch
Patch7:         lanp-Fix-error-response-from-Unsupported-Parameter-lookup.patch.txt
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  readline-devel
# Taken over from freeipmi.spec:
# Necessary as only those archs implement iopl and friends (#368541)
%ifarch %{ix86} x86_64 ia64 alpha aarch64
BuildRequires:  freeipmi-devel
%endif
%{?systemd_odering}

%description
This package contains a utility for interfacing with devices that
support the Intelligent Platform Management Interface specification.
IPMI is an open standard for machine health, inventory, and remote
power control.

This utility can communicate with IPMI-enabled devices through either a
kernel driver such as OpenIPMI or over the RMCP LAN protocol defined in
the IPMI specification.  IPMIv2 adds support for encrypted LAN
communications and remote Serial-over-LAN functionality.

It provides commands for reading the Sensor Data Repository (SDR) and
displaying sensor values, displaying the contents of the System Event
Log (SEL), printing Field Replaceable Unit (FRU) information, reading
and setting LAN configuration, and chassis power control.

%package bmc-snmp-proxy
Summary:        SNMP configuration to include the BMC's SNMP agent
Group:          System/Management
Requires:       net-snmp, ipmitool >= %{version}
BuildArch:      noarch

%description bmc-snmp-proxy
Given a host with BMC, this package would extend system configuration
of net-snmp to include redirections to BMC based SNMP.

%prep
%setup -q
%autopatch -p1

%build
cp %{SOURCE3} lib
autoreconf -fiv
# file-security: enables more security checks on files
%configure               \
  --enable-file-security \
  --enable-intf-usb \
  --enable-registry-download=no
make %{?_smp_mflags}

%install
%make_install
rm -rf %{buildroot}%{_datadir}/doc/ipmitool

install -D -m 644 %{SOURCE3}  %{buildroot}%{_datadir}/misc/enterprise-numbers

# exchange-bmc-os-info service
install -D -m 0755 contrib/exchange-bmc-os-info.init.redhat %{buildroot}/%{_sbindir}/exchange-bmc-os-info
install -D -m 0644 contrib/exchange-bmc-os-info.service.redhat %{buildroot}%{_unitdir}/exchange-bmc-os-info.service
install -D -m 0644 contrib/exchange-bmc-os-info.sysconf %{buildroot}/%{_sysconfdir}/exchange-bmc-os-info
ln -sf service %{buildroot}%{_sbindir}/rcexchange-bmc-os-info

# ipmievd service
install -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/ipmievd.service
install -D -m 644 %{SOURCE2} %{buildroot}/%{_sysconfdir}/ipmievd
ln -sf service %{buildroot}%{_sbindir}/rcipmievd

# bmc-snmp-proxy
install -D -m 755 contrib/bmc-snmp-proxy         %{buildroot}/%{_sbindir}/bmc-snmp-proxy
install -D -m 644 contrib/bmc-snmp-proxy.service %{buildroot}%{_unitdir}/bmc-snmp-proxy.service
install -D -m 755 contrib/bmc-snmp-proxy.sysconf %{buildroot}/%{_sysconfdir}/bmc-snmp-proxy
ln -sf service %{buildroot}%{_sbindir}/rcbmc-snmp-proxy

%pre
%service_add_pre exchange-bmc-os-info.service ipmievd.service

%post
%service_add_post exchange-bmc-os-info.service ipmievd.service

%preun
%service_del_preun exchange-bmc-os-info.service ipmievd.service

%postun
%service_del_postun exchange-bmc-os-info.service ipmievd.service

%pre bmc-snmp-proxy
%service_add_pre bmc-snmp-proxy.service

%post bmc-snmp-proxy
%service_add_post bmc-snmp-proxy.service exchange-bmc-os-info.service ipmievd.service

%preun bmc-snmp-proxy
%service_del_preun bmc-snmp-proxy.service exchange-bmc-os-info.service ipmievd.service

%postun bmc-snmp-proxy
%service_del_postun bmc-snmp-proxy.service exchange-bmc-os-info.service ipmievd.service

%files
%doc AUTHORS README ChangeLog
%license COPYING
%{_datadir}/ipmitool
%attr(755,root,root) %{_bindir}/ipmitool
%attr(755,root,root) %{_sbindir}/ipmievd
%attr(755,root,root) %{_sbindir}/exchange-bmc-os-info
%{_sbindir}/rcipmievd
%{_sbindir}/rcexchange-bmc-os-info
%config(noreplace) %{_sysconfdir}/exchange-bmc-os-info
%config(noreplace) %{_sysconfdir}/ipmievd
%{_unitdir}/exchange-bmc-os-info.service
%{_unitdir}/ipmievd.service
%{_mandir}/man1/*
%{_mandir}/man8/*
%{_datadir}/misc/enterprise-numbers

%files bmc-snmp-proxy
%attr(755,root,root) %{_sbindir}/bmc-snmp-proxy
%{_sbindir}/rcbmc-snmp-proxy
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/bmc-snmp-proxy
%{_unitdir}/bmc-snmp-proxy.service

%changelog
* Tue Oct 31 2023 Thomas Renninger <trenn@suse.de>
- bsc#1216556 L3: ipmitool: Unsupported LAN Parameter
    lookup error SLE15 SP4+
  Fix regression introduced by 351dad24a26f56580ba6
  lan: Add processing of get/set specific CCs:
  https://github.com/ipmitool/ipmitool/pull/388
  https://github.com/ipmitool/ipmitool/pull/389
  Be aware: Even the pullrequest is open for a while, this patch is not
  integrated in latest mainstream master branch.
  A    lanp-Fix-error-response-from-Unsupported-Parameter-lookup.patch.txt
  M    enterprise-numbers
* Mon Jul 24 2023 trenn@suse.de
- Fix: ipmitool duplicates the timestamp (bsc#1213390)
  A    Fix-time-format-for-sel-list-v.patch
- Remove: Make-IANA-PEN-download-configurable (is mainline)
  D 0006-Make-IANA-PEN-download-configurable-fix-uninitalized.patch
- Update to version 1.8.19.13.gbe11d94:
  * configure.ac: allow disabling registry downloads
  * lan: channel: Fix set alert on/off
  * make: use correct docdir variable provided by autotools
  * Do not require the IANA PEN registry file
  * configure.ac: fix readline static build
  * Update github actions for modern OSes
  * Update macos target name in github actions
  * delloem: Fix the unalign bug in arm64
  * lanplus: Realloc the msg if the payload_length gets updated
  * fru print: Add area checksum verification
  * fru: Add decoder for multirec system mgmt records
  * Fix enterprise-numbers URL
  * Update issue templates
* Wed Sep  7 2022 trenn@suse.de
- Update to version 1.8.19.0.g19d7878:
  * Release Version 1.8.19
  * Cast type before the left shift
  * sel: Fix the deasserted thresholds inequality
* Tue May 10 2022 moritz.kodytek@suse.com
- Update to version 1.8.18.249.g4d25a93:
  * man: Update the text for -C option
  * chassis restart_cause: Add new causes
  * sel: Remove redundant "Reserve SEL"
  * sdr: Fix modifier unit
  * Refactor bridging level detection to dedicated function
  * Fix double bridge detection in get_max_(req|rsp)_data_size()
* Wed Aug 11 2021 trenn@suse.de
- Update to version 1.8.18.238.gb7adc1d:
  * ipmi_mc: Fix the IPM_DEV_FWREV1_MAJOR_MASK
- Use %%{?systemd_ordering} instead of %%{?systemd_requires}
* Thu Jul  8 2021 trenn@suse.de
- Update to version 1.8.18+git20210622.11c7605:
  * Fix codefactor-io / CodeFactor warnings
  * Use /run instead of /var/run
  * oem: Update product IDs for YADRO
  * lan: Add processing of get/set specific CCs
  * lan: Refactor pointer style
  * doc: update lanplus doc to reflect default cipher suite change
  * ekanalyzer: Fix internal use area off-by-one bug
  * ekanalyzer frushow: Fix internal area size calc
  * sel: Fix "power supply inactive" flag offset
  * free: Fix implicit function declarations
  * Convert line endings to LF
- Update source file:
  M    enterprise-numbers
- Adopt to latest sources:
  M    0003-Cleanup-and-compiler-issues-only-no-functional-chang.patch
- Remove mainline patches:
  D    0007-bsc#1175328-check-for-correct-fd.patch
  D    0008-bsc#1181063-dont-parametrize-pidfile-name.patch
  D    Use-run-instead-of-var-run.patch
  D    lanplus-don-t-retry-pre-session-Get-cipher-suites.patch
- Config file in /etc must not be executable
  /etc/bmc-snmp-proxy
- Enhance _service file to always get latest sources and get the
  version correctly parsed
* Tue May 25 2021 Thomas Renninger <trenn@suse.de>
- Correct /etc/ipmievd config file to point to the new pidfile in /run
  not /var/run
* Wed Apr 28 2021 Thomas Renninger <trenn@suse.de>
- Use /run instead of /var/run (bsc#1185162)
  A Use-run-instead-of-var-run.patch
  Be aware that the patch has been submitted mainstream, therefore
  the git hash tag, but may not have been accepted.
* Wed Feb  3 2021 Thomas Renninger <trenn@suse.de>
- Fixes (bsc#1179133) lanplus: hanging on getting cipher suites for 10 seconds
  A lanplus-don-t-retry-pre-session-Get-cipher-suites.patch
* Thu Jan 28 2021 Josef Möllers <josef.moellers@suse.com>
- Do not append the device number to the PIDFILE pathname
  as this will confuse systemd.
  [bsc#1181063, 0008-bsc#1181063-dont-parametrize-pidfile-name.patch]
* Thu Jan 28 2021 Josef Möllers <josef.moellers@suse.com>
- When really starting the daemon, in lib/helper.c::ipmi_start_daemon()
  stdin/stdout/stderr are redirected to /dev/null and this is checked
  but the check for stderr tests for STDOUT_FILENO. This is, most
  likely, a copy-paste error.
  [bsc#1175328, 0007-bsc#1175328-check-for-correct-fd.patch]
* Wed Sep 23 2020 Klaus Kämpf <kkaempf@suse.com>
- clean up patches
  rename fwum_enhance_output.patch
  to 0001-Enhance-fwum-output.patch
  rename fix_file_permissions.patch
  to 0002-Fix-file-permissions.patch
  rename several_more_compile_fixes.patch
  to 0003-Cleanup-and-compiler-issues-only-no-functional-chang.patch
  rename ipmitool_adjust_suse_paths.patch
  to 0004-Adjust-SUSE-paths.patch
  rename hpm_x_compatibility_msg_is_debug_only.patch
  to 0005-HPM-x-compatibility-message-is-DEBUG-only.patch
  rename autotools_define_DOWNLOAD.diff
  to 0006-Make-IANA-PEN-download-configurable-fix-uninitalized.patch
* Wed Sep 23 2020 kkaempf@suse.com
- Update to version 1.8.18+git20200916.1245aaa387dc:
  * fru: Fix crashes on 6-bit ASCII strings
  * Refix 6e037d6bfbbb93b349c8ca331ebde03a837f76bf
  * oem: Add product ID for YADRO VEGMAN
  * configure.ac: add '--location' for curl to follow location
  * configure.ac: replace '-#' by '--progress-bar' with curl
  * log: refix 16f937a1: Add missing header changes
  * Add version info to debug output
  * doc, ci: Fix an error in package name for Windows
  * doc: Fix a small typo in INSTALL
  * RPM support: updated spec file changelog
* Tue Feb 11 2020 Ismail Dönmez <idonmez@suse.com>
- Don't hardcode /usr but use rpm variables
* Mon Feb 10 2020 trenn@suse.de
- bsc#1163026
- CVE-2020-5208
- Use license macro for COPYING, instead of doc
- Add ChangeLog mainline log to docs for shorter
  obs changelogs. This will be the last more detailed
  changelog, due to more important buffer overflow patches.
  Otherwise this changelog will not include (mainline) changes
  anymore.
- Update to version 1.8.18+git20200204.7ccea28:
  * fru, sdr: Fix id_string buffer overflows
  * lanp: Fix buffer overflows in get_lan_param_select
  * channel: Fix buffer overflow
  * session: Fix buffer overflow in ipmi_get_session_info
  * fru: Fix buffer overflow in ipmi_spd_print_fru
  * fru: Fix buffer overflow vulnerabilities
  * chassis: bootmbox: Refix 62a04390
  * configure: Drop requirement for curses et. al libs
- Add a configure option to disable IANA PEN database internet download
  A    autotools_define_DOWNLOAD.diff
  D    create_pen_list_from_local_file.patch
- New pen database:
  M    enterprise-numbers
- Patches adjusted to latest mainline code:
  M    fix_file_permissions.patch
  M    ipmitool_adjust_suse_paths.patch
  M    several_more_compile_fixes.patch
* Mon Sep  2 2019 trenn@suse.de
- Enable USB interface by explicit passing --enable-intf-usb (jira#SLE-7780)
- Enable free interface by adding freeipmi-devel package to
  build requires
* Wed Sep 26 2018 trenn@suse.de
- Update to latest git HEAD revision of 1.8.18 version
    commit 6f336d04f14b420822902dca7ef595cd49847d21
    Date:   Mon Sep 24 15:41:00 2018 +0200
- Change git repo and URL in spec from sourceforge to github
- Add download of iana pen list via _service
  from www.iana.org which is used to
  create a C include file at build time (lib/ipmi_pen_list.inc.c)
  Downloaded file added:
  A enterprise-numbers
- Add possiblity to create the include file from an already
  downloaded, local file
  A create_pen_list_from_local_file.patch
* Fri Jul 27 2018 jengelh@inai.de
- Use noun phrase in summary.
* Thu Jun 28 2018 josef.moellers@suse.com
- Make bmc-snmp-proxy into a (sub)package of its own.
  [fate#322044, ipmitool.spec]
* Fri Oct  6 2017 josef.moellers@suse.com
- Added missing references.
  [bsc#1041374,bsc#976123,bsc#988443,bsc#989985,bsc#968105,
  bsc#948540,fate#321578,fate#321579,fate#320439]
* Thu Jul 27 2017 tchvatal@suse.com
- Switch to OBS service to generate the tarball and changelog
  automatically from git "osc service dr"
- Update to version git checkout 20170406.ecb4cfb:
  * Prevent autoreconf from complaining about missing NEWS
  * Add git hash and dirty mark to ipmitool version
- Remove patch ipmitool_1_8_18_ecb4cfbff855_to_HEAD.patch as the
  patch is directly in the tarball
- Rename patch:
  ipmitool_adjust_suse.paths to ipmitool_adjust_suse_paths.patch
- Drop the --pic switch as it was only for static library
- Reduce the suse_version for 1210 check to switch systemd on as
  the package is not building on sle11 anyway
  * properly depend on systemd-rpm-macros and not full systemd
- Enable switch for file-security to be more strict on open files
* Wed Jul  5 2017 trenn@suse.de
- Update to latest git HEAD revision of 1.8.18 version
  commit ecb4cfbff855bb24099f2a80a6dd558518702c7d
  All these patches are now included in one big revision (1.8.18) to
  HEAD patch:
  D    0001-fix-typo.patch
  D    0002-added-microTCA-major-version.patch
  D    0003-replaced-removed-defines-which-are-already-present-i.patch
  D    0004-fix-typo.patch
  D    0006-ID-461-OpenSSL-1.1-compatibility-error-storage-size-.patch
  D    0007-ID-461-Make-compiler-happier-about-changes-related-t.patch
  D    0008-ID-474-Compile-fix-on-nonlinux-systems.patch
  D    0009-Add-bootstrap-support-for-Mac.patch
  D    0013-ID-478-ekanalyzer-Fixed-decoding-of-FRU-fields.patch
  D    0014-ID-479-ekanalyzer-fix-processing-of-custom-mfg.-fiel.patch
  D    0015-ID-477-fru-Fix-decoding-of-non-text-data-in-get_fru_.patch
  D    0017-ID-480-ipmitool-coredumps-in-EVP_CIPHER_CTX_init.patch
  This is the big revision (1.8.18) to HEAD patch:
  A    ipmitool_1_8_18_ecb4cfbff855_to_HEAD.patch
- Note: the tarball has been generated with git archive from the git
  repo. It slightly differs (.gitignore and configure.ac) from what
  was in osc before. No idea why, but the change is tiny and does not matter.
* Fri Apr 28 2017 trenn@suse.de
- Lower prio of message from error to debug (bsc#948540)
  A hpm_x_compatibility_msg_is_debug_only.patch
* Tue Mar 28 2017 trenn@suse.de
- Update to latest git HEAD version adding quite some fixes (fate#321578)
  * Add:
  0001-fix-typo.patch
  0002-added-microTCA-major-version.patch
  0003-replaced-removed-defines-which-are-already-present-i.patch
  0004-fix-typo.patch
  0006-ID-461-OpenSSL-1.1-compatibility-error-storage-size-.patch
  0007-ID-461-Make-compiler-happier-about-changes-related-t.patch
  0008-ID-474-Compile-fix-on-nonlinux-systems.patch
  0009-Add-bootstrap-support-for-Mac.patch
  0013-ID-478-ekanalyzer-Fixed-decoding-of-FRU-fields.patch
  0014-ID-479-ekanalyzer-fix-processing-of-custom-mfg.-fiel.patch
  0015-ID-477-fru-Fix-decoding-of-non-text-data-in-get_fru_.patch
  0017-ID-480-ipmitool-coredumps-in-EVP_CIPHER_CTX_init.patch
* Wed Jan 25 2017 felix.gerling@suse.com
- Update to latest version: 1.8.18 (fate#321579)
  D	0001-Incorporate-upstream-comments-to-289-add-whitespace.patch
* Tue May  3 2016 trenn@suse.de
- Update to latest version: 1.8.17
  D    ipmitool-1.8.10-implicit-fortify-decl.patch
  D    ipmitool-1_8_16_HEAD.patch
  D    latest_compile_fixes.patch
  D    ipmitool-sol_memleak.patch
  D    ipmitool-1_8_15_HEAD.patch
- Remove whitespace changes from:
  M    0001-Incorporate-upstream-comments-to-289-add-whitespace.patch
* Thu Feb 25 2016 trenn@suse.de
- Update to latest ipmitool source code
  commit 9020b67347f46554009591ae91e4fa8875c65dfa
  Date:   Tue Jan 12 21:16:37 2016 +0500
- Fix memleak: bnc#968105
  Add: ipmitool-sol_memleak.patch
* Wed Feb 24 2016 ro@suse.de
- do not use systemd macros for non-systemd distributions
* Wed Oct 14 2015 trenn@suse.de
- Update to latest ipmitool source code
  commit 999cd0ad9192b19ec57574e7aca111571f4d21d8
  Date:   Fri Mar 6 09:03:05 2015 -0600
  and throw away patches that went mainline.
  * Remove: fix_dell_oem_exitcode
* Wed Mar 11 2015 trenn@suse.de
- Add correct exit code on Dell specific commands which did not get mainline
  yet (bnc#886184)
  * Add patch: fix_dell_oem_exitcode
* Thu Jan 15 2015 trenn@suse.de
- Update to latest ipmitool sources.
  This is version 1.8.15 (git tag: IPMITOOL_1_8_15) plus mainline patches up
  to commit 708be8bc450f907cddb6d9e4b83aee6ba67b7d04
  Date:   Fri Jan 9 12:48:35 2015 +0100
  * Add: latest_compile_fixes.patch
  * Add: ipmitool-1_8_15_HEAD.patch
  * Remove: automake-1.13.patch
  * Remove: sdradd_close_file_handle.patch
  * Remove: ipmitool-1.8.10-implicit-fortify-decl.patch
* Thu Mar  6 2014 trenn@suse.de
- Update to latest git head and do not split up version 1.8.13.tar.bz2 tarball
  and patch to latest git HEAD.
  Reason is that all files in the repository got moved up one directory level
  by git commit:
  c18ec02f3304ce2a889a50e378f07a4168af3884
  Date:   Wed Feb 5 17:30:32 2014
  Move all files one level up in the file hierarchy, to avoid the useless
  ipmitool directory.
  We want the latest git head asap, because otherwise additionally needed
  patches will never patch cleanly in mainline and our repo and would always
  need adjusting.
  I asked for a new version tag mainline. As soon this happened, the
  tarball name should again match with the exact mainline git tag.
  Remove/Delete:
  ipmitool_update_to_git_head_31_01_2014_b0aad15d67007c74b.patch
- Incorporate patch on request from Dell: fate#315996
  Add: 0001-Incorporate-upstream-comments-to-289-add-whitespace.patch
* Thu Feb 13 2014 trenn@suse.de
- Added 3 services:
    1) exchange-bmc-os-info - fate#315999
    Shows SLES string as OS in the service processor info
    2) bmc-snmp-proxy - fate#316000
    Exports sel (BMC Error log) via snmpd
    3) ipmievd - fate#316002
    Logs sel to syslog
  1. and 2. are very Dell specific and should not get enabled by default
  3. got converted to a native systemd service. Still needs autoconf
  adjusting to get send mainline
  1. and 2. have somewhat bigger Init V init scripts and time was not
  enough to convert them. Therefore they were added via insserv
  and friends as well
  Add ipmitool_adjust_suse.paths
- Updated to latest git version:
  Add ipmitool_update_to_git_head_31_01_2014_b0aad15d67007c74b.patch
* Fri Oct  4 2013 kkaempf@suse.com
- Update to 1.8.13
  Changes: many, see
  http://sourceforge.net/projects/ipmitool/files/ipmitool/1.8.13/
- drop patches included upstream
  * compile-fixes.patch
  * ekanalyzer_fix_wrong_type_comparison.patch
  * increase_possible_fw_file_size.patch
  * ipmitool-bigendian.patch
  * old-gcc-options.patch
* Tue Jul 16 2013 tchvatal@suse.com
- Run format_spec_file so it is up par with others.
* Wed May 15 2013 kkaempf@suse.com
- fix GCC 4.3 build
  * Adds patch: old-gcc-options.patch
* Mon Mar 18 2013 dvaleev@suse.com
- fix build on BE arches (ipmitool-bigendian.patch)
* Thu Feb 28 2013 kkaempf@suse.com
- Adapt to Automake 1.13
* Thu Feb 28 2013 kkaempf@suse.com
- Version 1.8.12 released 2012-08-09
  Changes: many, see
  http://ipmitool.cvs.sourceforge.net/viewvc/ipmitool/ipmitool/ChangeLog?revision=1.37&view=markup&pathrev=IPMITOOL_1_8_12
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue May  4 2010 meissner@suse.de
- add a missing return value in one error branch.
* Thu Mar  4 2010 ro@suse.de
- fix one more no-return-in-nonvoid-function issue in ipmievd.c
* Thu Sep 17 2009 trenn@suse.de
- Fixed several compiler warnings (bnc#371131, bnc#480347, bnc#439490,
  bnc#525831, bnc#534909) and quite some more.
* Tue Sep 15 2009 trenn@suse.de
- Update to version 1.8.11
- Fix segfault when doing firmware upgrades with too big FW files
- Be more verbose why a firmware update does not match
* Tue Oct 14 2008 crrodriguez@suse.de
- fix implicit-fortify-decl errors
* Fri Sep 26 2008 duwe@suse.de
- fix ugly code and sloppy programming found by RPMlint
* Fri Sep 12 2008 duwe@suse.de
- update to version 1.8.10 as requested in FATE#304431
  + remove fixes now in mainline
* Thu Jan 17 2008 duwe@suse.de
- Fix bugs 298222 and 144023 (arg checking and POH scaling)
* Thu Mar  8 2007 duwe@suse.de
- add new compile fixes
* Wed Mar  7 2007 duwe@suse.de
- update to 1.8.9, fixing ipmievd crashing.
  This was requesten in Bug#246456
* Fri Oct 13 2006 duwe@suse.de
- update to today's CVS state
  * might fix SoL issues (Fate #30911)
* Tue Oct 10 2006 duwe@suse.de
- update to 1.8.8 mainly various fixes:
  version 1.8.8
  * Fix segfaults in sensor data repository list
  * Fix ipmievd to open interface before daemonizing
  * Fix IPMIv1.5 authtype NONE to ignore supplied password
  * Fix cipher suite display bug in lan print
  * Fix typo in IPMIv2 SOL output when sending break
  * Fix improper LUN handling with Tyan SOL
  * Add LUN support to OpenIPMI interface
  * Add support for Kontron OEM commands
  * Update to Kontron Firmware Update command
  version 1.8.7
  * Remove nuclear clause from license
  * Add Sun OEM command for blades
  * Increase argument size for raw commands in shell/exec
  * Fix handling of LUNs for LAN interfaces
  * Add IPMIv2 SOL loopback test
  * Add support for IBM OEM SEL messages
  * Disable file paranoia checks on read files by default
  * Support IPMIv2 SOL on older Intel boxes
  * Display message and exit if keepalive fails during SOL
  * Add support for setting VLAN id and priority
  * Add support for FreeBSD OpenIPMI-compatible driver
  * Add support for IPMIv2 Firmware Firewall
  * Fix gcc4 compile warnings
  * Make ipmievd generate pidfile
  * Add initscripts for ipmievd
* Mon May 29 2006 kukuk@suse.de
- Fix type conversion bug in ipmi_pef.c [#173658]
* Fri May 26 2006 schwab@suse.de
- Add readline-devel to BuildRequires to enable shell command.
- Fix use of channel_info bitfield.
- Fix byte swapping.
* Mon Feb 13 2006 kukuk@suse.de
- Update to ipmitool 1.8.6 [#134708,#131823]
  - Fix memory corruption when sending encrypted SOL traffic
  - Add keepalive timer to IPMIv2 SOL sessions
  - Raise privilege level after creating IPMIv2 session
  - Add support for settable SOL escape character with -e option
  - Add support for Kg BMC key for IPMIv2 authentication with -k option
  - Add support for Tyan IPMIv1.5 SOL with tsol command
  - Add support for PICMG devices
  - Add support for OEM SEL event parsing
  - Add support for command bridging over lan and lanplus interfaces
  - New 'chassis selftest' command
  - Many bufxies and patches from contributors
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Mon Sep 19 2005 kukuk@suse.de
- Fix missing return value
* Thu Aug  4 2005 kukuk@suse.de
- Initial release (FeatureID #165)
